---
name: Feature request
about: Suggest an idea for this project
---

<!--

Have you read wall's Code of Conduct? By filing an Issue, you are
expected to comply with it, including treating everyone with respect:
https://github.com/mbits-libs/wall/blob/master/CODE_OF_CONDUCT.md

-->

## Summary

_One paragraph explanation of the feature: a clear and concise description of what you want to happen._

## Motivation

_Why are we doing this? What use cases does it support? What is the expected outcome? A clear and concise description of what the problem is. Ex._ I'm always frustrated when [...]

## Describe alternatives you've considered

_A clear and concise description of the alternative solutions you've considered._

## Additional context

_Add any other context or screenshots about the feature request here._ 
